@@ -1,8 +1,8 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 
 ## Printing troubleshooter
 
-## Copyright (C) 2008 Red Hat, Inc.
+## Copyright (C) 2008, 2012 Red Hat, Inc.
 ## Copyright (C) 2008 Tim Waugh <twaugh@redhat.com>
 
 ## This program is free software; you can redistribute it and/or modify
@@ -19,10 +19,17 @@
 ## along with this program; if not, write to the Free Software
 ## Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+from gi.repository import Gtk
+
+class NoDevice:
+    pass
+
+NotListed = NoDevice()
+
 import cups
-import gobject
+from gi.repository import GObject
 from timedops import TimedOperation
-from base import *
+from .base import *
 class DeviceListed(Question):
     def __init__ (self, troubleshooter):
         # Is the device listed?
@@ -32,13 +39,13 @@ class DeviceListed(Question):
                                      "to use from the list below. "
                                      "If it does not appear in the list, "
                                      "select 'Not listed'."))
-        tv = gtk.TreeView ()
-        name = gtk.TreeViewColumn (_("Name"),
-                                   gtk.CellRendererText (), text=0)
-        info = gtk.TreeViewColumn (_("Information"),
-                                   gtk.CellRendererText (), text=1)
-        uri = gtk.TreeViewColumn (_("Device URI"),
-                                  gtk.CellRendererText (), text=2)
+        tv = Gtk.TreeView ()
+        name = Gtk.TreeViewColumn (_("Name"),
+                                   Gtk.CellRendererText (), text=0)
+        info = Gtk.TreeViewColumn (_("Information"),
+                                   Gtk.CellRendererText (), text=1)
+        uri = Gtk.TreeViewColumn (_("Device URI"),
+                                  Gtk.CellRendererText (), text=2)
         name.set_property ("resizable", True)
         info.set_property ("resizable", True)
         uri.set_property ("resizable", True)
@@ -46,9 +53,9 @@ class DeviceListed(Question):
         tv.append_column (info)
         tv.append_column (uri)
         tv.set_rules_hint (True)
-        sw = gtk.ScrolledWindow ()
-        sw.set_policy (gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-        sw.set_shadow_type (gtk.SHADOW_IN)
+        sw = Gtk.ScrolledWindow ()
+        sw.set_policy (Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
+        sw.set_shadow_type (Gtk.ShadowType.IN)
         sw.add (tv)
         page1.pack_start (sw, True, True, 0)
         self.treeview = tv
@@ -61,13 +68,13 @@ class DeviceListed(Question):
             answers.get ('cups_printer_remote', False)):
             return False
 
-        model = gtk.ListStore (gobject.TYPE_STRING,
-                               gobject.TYPE_STRING,
-                               gobject.TYPE_STRING,
-                               gobject.TYPE_PYOBJECT)
+        model = Gtk.ListStore (str,
+                               str,
+                               str,
+                               GObject.TYPE_PYOBJECT)
         self.treeview.set_model (model)
         iter = model.append (None)
-        model.set (iter, 0, _("Not listed"), 1, '', 2, '', 3, None)
+        model.set (iter, 0, _("Not listed"), 1, '', 2, '', 3, NotListed)
 
         devices = {}
         parent = self.troubleshooter.get_window ()
@@ -82,7 +89,7 @@ class DeviceListed(Question):
                                           parent=parent)
                 devices = self.op.run ()
                 devices_list = []
-                for uri, device in devices.iteritems ():
+                for uri, device in devices.items ():
                     if uri.find (':') == -1:
                         continue
 
@@ -93,7 +100,7 @@ class DeviceListed(Question):
                     info = device.get('device-make-and-model', _("Unknown"))
                     devices_list.append ((name, info, uri, device))
 
-                devices_list.sort (lambda x, y: cmp (x[0], y[0]))
+                devices_list.sort (key=lambda x: x[0])
                 for name, info, uri, device in devices_list:
                     iter = model.append (None)
                     model.set (iter, 0, name, 1, info, 2, uri, 3, device)
@@ -136,7 +143,7 @@ class DeviceListed(Question):
 
         model, iter = self.treeview.get_selection ().get_selected ()
         device = model.get_value (iter, 3)
-        if device == None:
+        if device == NotListed:
             class enum_devices:
                 def __init__ (self, model):
                     self.devices = {}
@@ -145,7 +152,7 @@ class DeviceListed(Question):
                 def each (self, model, path, iter, user_data):
                     uri = model.get_value (iter, 2)
                     device = model.get_value (iter, 3)
-                    if device:
+                    if device != NotListed:
                         self.devices[uri] = device
 
             self.answers['cups_device_listed'] = False
